@@ -3,18 +3,22 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
+from typing import List
+
 from jupyter_client.channelsabc import HBChannelABC
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Channel classes
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-class InProcessChannel(object):
+
+class InProcessChannel:
     """Base class for in-process channels."""
-    proxy_methods = []
+
+    proxy_methods: List[object] = []
 
     def __init__(self, client=None):
-        super(InProcessChannel, self).__init__()
+        super().__init__()
         self.client = client
         self._is_alive = False
 
@@ -28,18 +32,17 @@ class InProcessChannel(object):
         self._is_alive = False
 
     def call_handlers(self, msg):
-        """ This method is called in the main thread when a message arrives.
+        """This method is called in the main thread when a message arrives.
 
         Subclasses should override this method to handle incoming messages.
         """
-        raise NotImplementedError('call_handlers must be defined in a subclass.')
+        raise NotImplementedError("call_handlers must be defined in a subclass.")
 
     def flush(self, timeout=1.0):
         pass
 
-
     def call_handlers_later(self, *args, **kwds):
-        """ Call the message handlers later.
+        """Call the message handlers later.
 
         The default implementation just calls the handlers immediately, but this
         method exists so that GUI toolkits can defer calling the handlers until
@@ -48,7 +51,7 @@ class InProcessChannel(object):
         self.call_handlers(*args, **kwds)
 
     def process_events(self):
-        """ Process any pending GUI events.
+        """Process any pending GUI events.
 
         This method will be never be called from a frontend without an event
         loop (e.g., a terminal frontend).
@@ -56,8 +59,7 @@ class InProcessChannel(object):
         raise NotImplementedError
 
 
-
-class InProcessHBChannel(object):
+class InProcessHBChannel:
     """A dummy heartbeat channel interface for in-process kernels.
 
     Normally we use the heartbeat to check that the kernel process is alive.
@@ -68,7 +70,7 @@ class InProcessHBChannel(object):
     time_to_dead = 3.0
 
     def __init__(self, client=None):
-        super(InProcessHBChannel, self).__init__()
+        super().__init__()
         self.client = client
         self._is_alive = False
         self._pause = True
